@@ -56,6 +56,7 @@ from google.cloud.appengine_admin_v1.types import operation as ga_operation
 from .transports.base import DEFAULT_CLIENT_INFO, ApplicationsTransport
 from .transports.grpc import ApplicationsGrpcTransport
 from .transports.grpc_asyncio import ApplicationsGrpcAsyncIOTransport
+from .transports.rest import ApplicationsRestTransport
 
 
 class ApplicationsClientMeta(type):
@@ -69,6 +70,7 @@ class ApplicationsClientMeta(type):
     _transport_registry = OrderedDict()  # type: Dict[str, Type[ApplicationsTransport]]
     _transport_registry["grpc"] = ApplicationsGrpcTransport
     _transport_registry["grpc_asyncio"] = ApplicationsGrpcAsyncIOTransport
+    _transport_registry["rest"] = ApplicationsRestTransport
 
     def get_transport_class(
         cls,
@@ -459,8 +461,7 @@ class ApplicationsClient(metaclass=ApplicationsClientMeta):
 
         Args:
             request (Union[google.cloud.appengine_admin_v1.types.GetApplicationRequest, dict]):
-                The request object. Request message for
-                `Applications.GetApplication`.
+                The request object. Request message for ``Applications.GetApplication``.
             name (str):
                 Name of the Application resource to get. Example:
                 ``apps/myapp``.
@@ -574,8 +575,7 @@ class ApplicationsClient(metaclass=ApplicationsClientMeta):
 
         Args:
             request (Union[google.cloud.appengine_admin_v1.types.CreateApplicationRequest, dict]):
-                The request object. Request message for
-                `Applications.CreateApplication`.
+                The request object. Request message for ``Applications.CreateApplication``.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -670,8 +670,7 @@ class ApplicationsClient(metaclass=ApplicationsClientMeta):
 
         Args:
             request (Union[google.cloud.appengine_admin_v1.types.UpdateApplicationRequest, dict]):
-                The request object. Request message for
-                `Applications.UpdateApplication`.
+                The request object. Request message for ``Applications.UpdateApplication``.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
