@@ -262,7 +262,7 @@ class AuthorizedCertificatesAsyncClient:
         Args:
             request (Optional[Union[google.cloud.appengine_admin_v1.types.ListAuthorizedCertificatesRequest, dict]]):
                 The request object. Request message for
-                `AuthorizedCertificates.ListAuthorizedCertificates`.
+                ``AuthorizedCertificates.ListAuthorizedCertificates``.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -355,7 +355,7 @@ class AuthorizedCertificatesAsyncClient:
         Args:
             request (Optional[Union[google.cloud.appengine_admin_v1.types.GetAuthorizedCertificateRequest, dict]]):
                 The request object. Request message for
-                `AuthorizedCertificates.GetAuthorizedCertificate`.
+                ``AuthorizedCertificates.GetAuthorizedCertificate``.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -439,7 +439,7 @@ class AuthorizedCertificatesAsyncClient:
         Args:
             request (Optional[Union[google.cloud.appengine_admin_v1.types.CreateAuthorizedCertificateRequest, dict]]):
                 The request object. Request message for
-                `AuthorizedCertificates.CreateAuthorizedCertificate`.
+                ``AuthorizedCertificates.CreateAuthorizedCertificate``.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -528,7 +528,7 @@ class AuthorizedCertificatesAsyncClient:
         Args:
             request (Optional[Union[google.cloud.appengine_admin_v1.types.UpdateAuthorizedCertificateRequest, dict]]):
                 The request object. Request message for
-                `AuthorizedCertificates.UpdateAuthorizedCertificate`.
+                ``AuthorizedCertificates.UpdateAuthorizedCertificate``.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -609,7 +609,7 @@ class AuthorizedCertificatesAsyncClient:
         Args:
             request (Optional[Union[google.cloud.appengine_admin_v1.types.DeleteAuthorizedCertificateRequest, dict]]):
                 The request object. Request message for
-                `AuthorizedCertificates.DeleteAuthorizedCertificate`.
+                ``AuthorizedCertificates.DeleteAuthorizedCertificate``.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
