@@ -54,6 +54,7 @@ from google.cloud.appengine_admin_v1.types import appengine, certificate
 from .transports.base import DEFAULT_CLIENT_INFO, AuthorizedCertificatesTransport
 from .transports.grpc import AuthorizedCertificatesGrpcTransport
 from .transports.grpc_asyncio import AuthorizedCertificatesGrpcAsyncIOTransport
+from .transports.rest import AuthorizedCertificatesRestTransport
 
 
 class AuthorizedCertificatesClientMeta(type):
@@ -69,6 +70,7 @@ class AuthorizedCertificatesClientMeta(type):
     )  # type: Dict[str, Type[AuthorizedCertificatesTransport]]
     _transport_registry["grpc"] = AuthorizedCertificatesGrpcTransport
     _transport_registry["grpc_asyncio"] = AuthorizedCertificatesGrpcAsyncIOTransport
+    _transport_registry["rest"] = AuthorizedCertificatesRestTransport
 
     def get_transport_class(
         cls,
@@ -466,7 +468,7 @@ class AuthorizedCertificatesClient(metaclass=AuthorizedCertificatesClientMeta):
         Args:
             request (Union[google.cloud.appengine_admin_v1.types.ListAuthorizedCertificatesRequest, dict]):
                 The request object. Request message for
-                `AuthorizedCertificates.ListAuthorizedCertificates`.
+                ``AuthorizedCertificates.ListAuthorizedCertificates``.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -562,7 +564,7 @@ class AuthorizedCertificatesClient(metaclass=AuthorizedCertificatesClientMeta):
         Args:
             request (Union[google.cloud.appengine_admin_v1.types.GetAuthorizedCertificateRequest, dict]):
                 The request object. Request message for
-                `AuthorizedCertificates.GetAuthorizedCertificate`.
+                ``AuthorizedCertificates.GetAuthorizedCertificate``.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -649,7 +651,7 @@ class AuthorizedCertificatesClient(metaclass=AuthorizedCertificatesClientMeta):
         Args:
             request (Union[google.cloud.appengine_admin_v1.types.CreateAuthorizedCertificateRequest, dict]):
                 The request object. Request message for
-                `AuthorizedCertificates.CreateAuthorizedCertificate`.
+                ``AuthorizedCertificates.CreateAuthorizedCertificate``.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -741,7 +743,7 @@ class AuthorizedCertificatesClient(metaclass=AuthorizedCertificatesClientMeta):
         Args:
             request (Union[google.cloud.appengine_admin_v1.types.UpdateAuthorizedCertificateRequest, dict]):
                 The request object. Request message for
-                `AuthorizedCertificates.UpdateAuthorizedCertificate`.
+                ``AuthorizedCertificates.UpdateAuthorizedCertificate``.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -825,7 +827,7 @@ class AuthorizedCertificatesClient(metaclass=AuthorizedCertificatesClientMeta):
         Args:
             request (Union[google.cloud.appengine_admin_v1.types.DeleteAuthorizedCertificateRequest, dict]):
                 The request object. Request message for
-                `AuthorizedCertificates.DeleteAuthorizedCertificate`.
+                ``AuthorizedCertificates.DeleteAuthorizedCertificate``.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
