@@ -256,7 +256,7 @@ class DomainMappingsAsyncClient:
         Args:
             request (Optional[Union[google.cloud.appengine_admin_v1.types.ListDomainMappingsRequest, dict]]):
                 The request object. Request message for
-                `DomainMappings.ListDomainMappings`.
+                ``DomainMappings.ListDomainMappings``.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -345,8 +345,7 @@ class DomainMappingsAsyncClient:
 
         Args:
             request (Optional[Union[google.cloud.appengine_admin_v1.types.GetDomainMappingRequest, dict]]):
-                The request object. Request message for
-                `DomainMappings.GetDomainMapping`.
+                The request object. Request message for ``DomainMappings.GetDomainMapping``.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -432,7 +431,7 @@ class DomainMappingsAsyncClient:
         Args:
             request (Optional[Union[google.cloud.appengine_admin_v1.types.CreateDomainMappingRequest, dict]]):
                 The request object. Request message for
-                `DomainMappings.CreateDomainMapping`.
+                ``DomainMappings.CreateDomainMapping``.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -530,7 +529,7 @@ class DomainMappingsAsyncClient:
         Args:
             request (Optional[Union[google.cloud.appengine_admin_v1.types.UpdateDomainMappingRequest, dict]]):
                 The request object. Request message for
-                `DomainMappings.UpdateDomainMapping`.
+                ``DomainMappings.UpdateDomainMapping``.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -626,7 +625,7 @@ class DomainMappingsAsyncClient:
         Args:
             request (Optional[Union[google.cloud.appengine_admin_v1.types.DeleteDomainMappingRequest, dict]]):
                 The request object. Request message for
-                `DomainMappings.DeleteDomainMapping`.
+                ``DomainMappings.DeleteDomainMapping``.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
