@@ -57,6 +57,7 @@ from google.cloud.appengine_admin_v1.types import operation as ga_operation
 from .transports.base import DEFAULT_CLIENT_INFO, DomainMappingsTransport
 from .transports.grpc import DomainMappingsGrpcTransport
 from .transports.grpc_asyncio import DomainMappingsGrpcAsyncIOTransport
+from .transports.rest import DomainMappingsRestTransport
 
 
 class DomainMappingsClientMeta(type):
@@ -72,6 +73,7 @@ class DomainMappingsClientMeta(type):
     )  # type: Dict[str, Type[DomainMappingsTransport]]
     _transport_registry["grpc"] = DomainMappingsGrpcTransport
     _transport_registry["grpc_asyncio"] = DomainMappingsGrpcAsyncIOTransport
+    _transport_registry["rest"] = DomainMappingsRestTransport
 
     def get_transport_class(
         cls,
@@ -463,7 +465,7 @@ class DomainMappingsClient(metaclass=DomainMappingsClientMeta):
         Args:
             request (Union[google.cloud.appengine_admin_v1.types.ListDomainMappingsRequest, dict]):
                 The request object. Request message for
-                `DomainMappings.ListDomainMappings`.
+                ``DomainMappings.ListDomainMappings``.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -553,8 +555,7 @@ class DomainMappingsClient(metaclass=DomainMappingsClientMeta):
 
         Args:
             request (Union[google.cloud.appengine_admin_v1.types.GetDomainMappingRequest, dict]):
-                The request object. Request message for
-                `DomainMappings.GetDomainMapping`.
+                The request object. Request message for ``DomainMappings.GetDomainMapping``.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -641,7 +642,7 @@ class DomainMappingsClient(metaclass=DomainMappingsClientMeta):
         Args:
             request (Union[google.cloud.appengine_admin_v1.types.CreateDomainMappingRequest, dict]):
                 The request object. Request message for
-                `DomainMappings.CreateDomainMapping`.
+                ``DomainMappings.CreateDomainMapping``.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -740,7 +741,7 @@ class DomainMappingsClient(metaclass=DomainMappingsClientMeta):
         Args:
             request (Union[google.cloud.appengine_admin_v1.types.UpdateDomainMappingRequest, dict]):
                 The request object. Request message for
-                `DomainMappings.UpdateDomainMapping`.
+                ``DomainMappings.UpdateDomainMapping``.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -837,7 +838,7 @@ class DomainMappingsClient(metaclass=DomainMappingsClientMeta):
         Args:
             request (Union[google.cloud.appengine_admin_v1.types.DeleteDomainMappingRequest, dict]):
                 The request object. Request message for
-                `DomainMappings.DeleteDomainMapping`.
+                ``DomainMappings.DeleteDomainMapping``.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
