@@ -253,8 +253,7 @@ class FirewallAsyncClient:
 
         Args:
             request (Optional[Union[google.cloud.appengine_admin_v1.types.ListIngressRulesRequest, dict]]):
-                The request object. Request message for
-                `Firewall.ListIngressRules`.
+                The request object. Request message for ``Firewall.ListIngressRules``.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -350,7 +349,7 @@ class FirewallAsyncClient:
         Args:
             request (Optional[Union[google.cloud.appengine_admin_v1.types.BatchUpdateIngressRulesRequest, dict]]):
                 The request object. Request message for
-                `Firewall.BatchUpdateIngressRules`.
+                ``Firewall.BatchUpdateIngressRules``.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -426,8 +425,7 @@ class FirewallAsyncClient:
 
         Args:
             request (Optional[Union[google.cloud.appengine_admin_v1.types.CreateIngressRuleRequest, dict]]):
-                The request object. Request message for
-                `Firewall.CreateIngressRule`.
+                The request object. Request message for ``Firewall.CreateIngressRule``.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -507,8 +505,7 @@ class FirewallAsyncClient:
 
         Args:
             request (Optional[Union[google.cloud.appengine_admin_v1.types.GetIngressRuleRequest, dict]]):
-                The request object. Request message for
-                `Firewall.GetIngressRule`.
+                The request object. Request message for ``Firewall.GetIngressRule``.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -588,8 +585,7 @@ class FirewallAsyncClient:
 
         Args:
             request (Optional[Union[google.cloud.appengine_admin_v1.types.UpdateIngressRuleRequest, dict]]):
-                The request object. Request message for
-                `Firewall.UpdateIngressRule`.
+                The request object. Request message for ``Firewall.UpdateIngressRule``.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -666,8 +662,7 @@ class FirewallAsyncClient:
 
         Args:
             request (Optional[Union[google.cloud.appengine_admin_v1.types.DeleteIngressRuleRequest, dict]]):
-                The request object. Request message for
-                `Firewall.DeleteIngressRule`.
+                The request object. Request message for ``Firewall.DeleteIngressRule``.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
