@@ -52,6 +52,7 @@ from google.cloud.appengine_admin_v1.types import appengine, firewall
 from .transports.base import DEFAULT_CLIENT_INFO, FirewallTransport
 from .transports.grpc import FirewallGrpcTransport
 from .transports.grpc_asyncio import FirewallGrpcAsyncIOTransport
+from .transports.rest import FirewallRestTransport
 
 
 class FirewallClientMeta(type):
@@ -65,6 +66,7 @@ class FirewallClientMeta(type):
     _transport_registry = OrderedDict()  # type: Dict[str, Type[FirewallTransport]]
     _transport_registry["grpc"] = FirewallGrpcTransport
     _transport_registry["grpc_asyncio"] = FirewallGrpcAsyncIOTransport
+    _transport_registry["rest"] = FirewallRestTransport
 
     def get_transport_class(
         cls,
@@ -466,8 +468,7 @@ class FirewallClient(metaclass=FirewallClientMeta):
 
         Args:
             request (Union[google.cloud.appengine_admin_v1.types.ListIngressRulesRequest, dict]):
-                The request object. Request message for
-                `Firewall.ListIngressRules`.
+                The request object. Request message for ``Firewall.ListIngressRules``.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -564,7 +565,7 @@ class FirewallClient(metaclass=FirewallClientMeta):
         Args:
             request (Union[google.cloud.appengine_admin_v1.types.BatchUpdateIngressRulesRequest, dict]):
                 The request object. Request message for
-                `Firewall.BatchUpdateIngressRules`.
+                ``Firewall.BatchUpdateIngressRules``.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -643,8 +644,7 @@ class FirewallClient(metaclass=FirewallClientMeta):
 
         Args:
             request (Union[google.cloud.appengine_admin_v1.types.CreateIngressRuleRequest, dict]):
-                The request object. Request message for
-                `Firewall.CreateIngressRule`.
+                The request object. Request message for ``Firewall.CreateIngressRule``.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -725,8 +725,7 @@ class FirewallClient(metaclass=FirewallClientMeta):
 
         Args:
             request (Union[google.cloud.appengine_admin_v1.types.GetIngressRuleRequest, dict]):
-                The request object. Request message for
-                `Firewall.GetIngressRule`.
+                The request object. Request message for ``Firewall.GetIngressRule``.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -807,8 +806,7 @@ class FirewallClient(metaclass=FirewallClientMeta):
 
         Args:
             request (Union[google.cloud.appengine_admin_v1.types.UpdateIngressRuleRequest, dict]):
-                The request object. Request message for
-                `Firewall.UpdateIngressRule`.
+                The request object. Request message for ``Firewall.UpdateIngressRule``.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -886,8 +884,7 @@ class FirewallClient(metaclass=FirewallClientMeta):
 
         Args:
             request (Union[google.cloud.appengine_admin_v1.types.DeleteIngressRuleRequest, dict]):
-                The request object. Request message for
-                `Firewall.DeleteIngressRule`.
+                The request object. Request message for ``Firewall.DeleteIngressRule``.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
