@@ -58,6 +58,7 @@ from google.cloud.appengine_admin_v1.types import operation as ga_operation
 from .transports.base import DEFAULT_CLIENT_INFO, InstancesTransport
 from .transports.grpc import InstancesGrpcTransport
 from .transports.grpc_asyncio import InstancesGrpcAsyncIOTransport
+from .transports.rest import InstancesRestTransport
 
 
 class InstancesClientMeta(type):
@@ -71,6 +72,7 @@ class InstancesClientMeta(type):
     _transport_registry = OrderedDict()  # type: Dict[str, Type[InstancesTransport]]
     _transport_registry["grpc"] = InstancesGrpcTransport
     _transport_registry["grpc_asyncio"] = InstancesGrpcAsyncIOTransport
+    _transport_registry["rest"] = InstancesRestTransport
 
     def get_transport_class(
         cls,
@@ -489,8 +491,7 @@ class InstancesClient(metaclass=InstancesClientMeta):
 
         Args:
             request (Union[google.cloud.appengine_admin_v1.types.ListInstancesRequest, dict]):
-                The request object. Request message for
-                `Instances.ListInstances`.
+                The request object. Request message for ``Instances.ListInstances``.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -580,8 +581,7 @@ class InstancesClient(metaclass=InstancesClientMeta):
 
         Args:
             request (Union[google.cloud.appengine_admin_v1.types.GetInstanceRequest, dict]):
-                The request object. Request message for
-                `Instances.GetInstance`.
+                The request object. Request message for ``Instances.GetInstance``.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -679,8 +679,7 @@ class InstancesClient(metaclass=InstancesClientMeta):
 
         Args:
             request (Union[google.cloud.appengine_admin_v1.types.DeleteInstanceRequest, dict]):
-                The request object. Request message for
-                `Instances.DeleteInstance`.
+                The request object. Request message for ``Instances.DeleteInstance``.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -790,8 +789,7 @@ class InstancesClient(metaclass=InstancesClientMeta):
 
         Args:
             request (Union[google.cloud.appengine_admin_v1.types.DebugInstanceRequest, dict]):
-                The request object. Request message for
-                `Instances.DebugInstance`.
+                The request object. Request message for ``Instances.DebugInstance``.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
