@@ -248,8 +248,7 @@ class ServicesAsyncClient:
 
         Args:
             request (Optional[Union[google.cloud.appengine_admin_v1.types.ListServicesRequest, dict]]):
-                The request object. Request message for
-                `Services.ListServices`.
+                The request object. Request message for ``Services.ListServices``.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -339,8 +338,7 @@ class ServicesAsyncClient:
 
         Args:
             request (Optional[Union[google.cloud.appengine_admin_v1.types.GetServiceRequest, dict]]):
-                The request object. Request message for
-                `Services.GetService`.
+                The request object. Request message for ``Services.GetService``.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -432,8 +430,7 @@ class ServicesAsyncClient:
 
         Args:
             request (Optional[Union[google.cloud.appengine_admin_v1.types.UpdateServiceRequest, dict]]):
-                The request object. Request message for
-                `Services.UpdateService`.
+                The request object. Request message for ``Services.UpdateService``.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -533,8 +530,7 @@ class ServicesAsyncClient:
 
         Args:
             request (Optional[Union[google.cloud.appengine_admin_v1.types.DeleteServiceRequest, dict]]):
-                The request object. Request message for
-                `Services.DeleteService`.
+                The request object. Request message for ``Services.DeleteService``.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
