@@ -58,6 +58,7 @@ from google.cloud.appengine_admin_v1.types import service
 from .transports.base import DEFAULT_CLIENT_INFO, ServicesTransport
 from .transports.grpc import ServicesGrpcTransport
 from .transports.grpc_asyncio import ServicesGrpcAsyncIOTransport
+from .transports.rest import ServicesRestTransport
 
 
 class ServicesClientMeta(type):
@@ -71,6 +72,7 @@ class ServicesClientMeta(type):
     _transport_registry = OrderedDict()  # type: Dict[str, Type[ServicesTransport]]
     _transport_registry["grpc"] = ServicesGrpcTransport
     _transport_registry["grpc_asyncio"] = ServicesGrpcAsyncIOTransport
+    _transport_registry["rest"] = ServicesRestTransport
 
     def get_transport_class(
         cls,
@@ -461,8 +463,7 @@ class ServicesClient(metaclass=ServicesClientMeta):
 
         Args:
             request (Union[google.cloud.appengine_admin_v1.types.ListServicesRequest, dict]):
-                The request object. Request message for
-                `Services.ListServices`.
+                The request object. Request message for ``Services.ListServices``.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -553,8 +554,7 @@ class ServicesClient(metaclass=ServicesClientMeta):
 
         Args:
             request (Union[google.cloud.appengine_admin_v1.types.GetServiceRequest, dict]):
-                The request object. Request message for
-                `Services.GetService`.
+                The request object. Request message for ``Services.GetService``.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -647,8 +647,7 @@ class ServicesClient(metaclass=ServicesClientMeta):
 
         Args:
             request (Union[google.cloud.appengine_admin_v1.types.UpdateServiceRequest, dict]):
-                The request object. Request message for
-                `Services.UpdateService`.
+                The request object. Request message for ``Services.UpdateService``.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -749,8 +748,7 @@ class ServicesClient(metaclass=ServicesClientMeta):
 
         Args:
             request (Union[google.cloud.appengine_admin_v1.types.DeleteServiceRequest, dict]):
-                The request object. Request message for
-                `Services.DeleteService`.
+                The request object. Request message for ``Services.DeleteService``.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
