@@ -13,6 +13,8 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
+from __future__ import annotations
+
 from typing import MutableMapping, MutableSequence
 
 from google.protobuf import timestamp_pb2  # type: ignore
@@ -35,7 +37,7 @@ class ManagementStatus(proto.Enum):
 
     Values:
         MANAGEMENT_STATUS_UNSPECIFIED (0):
-
+            No description available.
         OK (1):
             Certificate was successfully obtained and
             inserted into the serving system.
