@@ -13,6 +13,8 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
+from __future__ import annotations
+
 from typing import MutableMapping, MutableSequence
 
 import proto  # type: ignore
@@ -65,7 +67,7 @@ class FirewallRule(proto.Message):
 
         Values:
             UNSPECIFIED_ACTION (0):
-
+                No description available.
             ALLOW (1):
                 Matching requests are allowed.
             DENY (2):
