@@ -13,6 +13,8 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
+from __future__ import annotations
+
 from typing import MutableMapping, MutableSequence
 
 from google.protobuf import duration_pb2  # type: ignore
@@ -1036,7 +1038,7 @@ class VpcAccessConnector(proto.Message):
 
         Values:
             EGRESS_SETTING_UNSPECIFIED (0):
-
+                No description available.
             ALL_TRAFFIC (1):
                 Force the use of VPC Access for all egress
                 traffic from the function.
