@@ -22,6 +22,8 @@ try:
 except ImportError:  # pragma: NO COVER
     import mock
 
+from collections.abc import Iterable
+import json
 import math
 
 from google.api_core import gapic_v1, grpc_helpers, grpc_helpers_async, path_template
@@ -31,11 +33,14 @@ import google.auth
 from google.auth import credentials as ga_credentials
 from google.auth.exceptions import MutualTLSChannelError
 from google.oauth2 import service_account
+from google.protobuf import json_format
 import grpc
 from grpc.experimental import aio
 from proto.marshal.rules import wrappers
 from proto.marshal.rules.dates import DurationRule, TimestampRule
 import pytest
+from requests import PreparedRequest, Request, Response
+from requests.sessions import Session
 
 from google.cloud.appengine_admin_v1.services.authorized_domains import (
     AuthorizedDomainsAsyncClient,
@@ -96,6 +101,7 @@ def test__get_default_mtls_endpoint():
     [
         (AuthorizedDomainsClient, "grpc"),
         (AuthorizedDomainsAsyncClient, "grpc_asyncio"),
+        (AuthorizedDomainsClient, "rest"),
     ],
 )
 def test_authorized_domains_client_from_service_account_info(
@@ -111,7 +117,11 @@ def test_authorized_domains_client_from_service_account_info(
         assert client.transport._credentials == creds
         assert isinstance(client, client_class)
 
-        assert client.transport._host == ("appengine.googleapis.com:443")
+        assert client.transport._host == (
+            "appengine.googleapis.com:443"
+            if transport_name in ["grpc", "grpc_asyncio"]
+            else "https://appengine.googleapis.com"
+        )
 
 
 @pytest.mark.parametrize(
@@ -119,6 +129,7 @@ def test_authorized_domains_client_from_service_account_info(
     [
         (transports.AuthorizedDomainsGrpcTransport, "grpc"),
         (transports.AuthorizedDomainsGrpcAsyncIOTransport, "grpc_asyncio"),
+        (transports.AuthorizedDomainsRestTransport, "rest"),
     ],
 )
 def test_authorized_domains_client_service_account_always_use_jwt(
@@ -144,6 +155,7 @@ def test_authorized_domains_client_service_account_always_use_jwt(
     [
         (AuthorizedDomainsClient, "grpc"),
         (AuthorizedDomainsAsyncClient, "grpc_asyncio"),
+        (AuthorizedDomainsClient, "rest"),
     ],
 )
 def test_authorized_domains_client_from_service_account_file(
@@ -166,13 +178,18 @@ def test_authorized_domains_client_from_service_account_file(
         assert client.transport._credentials == creds
         assert isinstance(client, client_class)
 
-        assert client.transport._host == ("appengine.googleapis.com:443")
+        assert client.transport._host == (
+            "appengine.googleapis.com:443"
+            if transport_name in ["grpc", "grpc_asyncio"]
+            else "https://appengine.googleapis.com"
+        )
 
 
 def test_authorized_domains_client_get_transport_class():
     transport = AuthorizedDomainsClient.get_transport_class()
     available_transports = [
         transports.AuthorizedDomainsGrpcTransport,
+        transports.AuthorizedDomainsRestTransport,
     ]
     assert transport in available_transports
 
@@ -189,6 +206,7 @@ def test_authorized_domains_client_get_transport_class():
             transports.AuthorizedDomainsGrpcAsyncIOTransport,
             "grpc_asyncio",
         ),
+        (AuthorizedDomainsClient, transports.AuthorizedDomainsRestTransport, "rest"),
     ],
 )
 @mock.patch.object(
@@ -344,6 +362,18 @@ def test_authorized_domains_client_client_options(
             "grpc_asyncio",
             "false",
         ),
+        (
+            AuthorizedDomainsClient,
+            transports.AuthorizedDomainsRestTransport,
+            "rest",
+            "true",
+        ),
+        (
+            AuthorizedDomainsClient,
+            transports.AuthorizedDomainsRestTransport,
+            "rest",
+            "false",
+        ),
     ],
 )
 @mock.patch.object(
@@ -543,6 +573,7 @@ def test_authorized_domains_client_get_mtls_endpoint_and_cert_source(client_clas
             transports.AuthorizedDomainsGrpcAsyncIOTransport,
             "grpc_asyncio",
         ),
+        (AuthorizedDomainsClient, transports.AuthorizedDomainsRestTransport, "rest"),
     ],
 )
 def test_authorized_domains_client_client_options_scopes(
@@ -583,6 +614,12 @@ def test_authorized_domains_client_client_options_scopes(
             "grpc_asyncio",
             grpc_helpers_async,
         ),
+        (
+            AuthorizedDomainsClient,
+            transports.AuthorizedDomainsRestTransport,
+            "rest",
+            None,
+        ),
     ],
 )
 def test_authorized_domains_client_client_options_credentials_file(
@@ -1055,6 +1092,189 @@ async def test_list_authorized_domains_async_pages():
             assert page_.raw_page.next_page_token == token
 
 
+@pytest.mark.parametrize(
+    "request_type",
+    [
+        appengine.ListAuthorizedDomainsRequest,
+        dict,
+    ],
+)
+def test_list_authorized_domains_rest(request_type):
+    client = AuthorizedDomainsClient(
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport="rest",
+    )
+
+    # send a request that will satisfy transcoding
+    request_init = {"parent": "apps/sample1"}
+    request = request_type(**request_init)
+
+    # Mock the http request call within the method and fake a response.
+    with mock.patch.object(type(client.transport._session), "request") as req:
+        # Designate an appropriate value for the returned response.
+        return_value = appengine.ListAuthorizedDomainsResponse(
+            next_page_token="next_page_token_value",
+        )
+
+        # Wrap the value into a proper Response obj
+        response_value = Response()
+        response_value.status_code = 200
+        pb_return_value = appengine.ListAuthorizedDomainsResponse.pb(return_value)
+        json_return_value = json_format.MessageToJson(pb_return_value)
+
+        response_value._content = json_return_value.encode("UTF-8")
+        req.return_value = response_value
+        response = client.list_authorized_domains(request)
+
+    # Establish that the response is the type that we expect.
+    assert isinstance(response, pagers.ListAuthorizedDomainsPager)
+    assert response.next_page_token == "next_page_token_value"
+
+
+@pytest.mark.parametrize("null_interceptor", [True, False])
+def test_list_authorized_domains_rest_interceptors(null_interceptor):
+    transport = transports.AuthorizedDomainsRestTransport(
+        credentials=ga_credentials.AnonymousCredentials(),
+        interceptor=None
+        if null_interceptor
+        else transports.AuthorizedDomainsRestInterceptor(),
+    )
+    client = AuthorizedDomainsClient(transport=transport)
+    with mock.patch.object(
+        type(client.transport._session), "request"
+    ) as req, mock.patch.object(
+        path_template, "transcode"
+    ) as transcode, mock.patch.object(
+        transports.AuthorizedDomainsRestInterceptor, "post_list_authorized_domains"
+    ) as post, mock.patch.object(
+        transports.AuthorizedDomainsRestInterceptor, "pre_list_authorized_domains"
+    ) as pre:
+        pre.assert_not_called()
+        post.assert_not_called()
+        pb_message = appengine.ListAuthorizedDomainsRequest.pb(
+            appengine.ListAuthorizedDomainsRequest()
+        )
+        transcode.return_value = {
+            "method": "post",
+            "uri": "my_uri",
+            "body": pb_message,
+            "query_params": pb_message,
+        }
+
+        req.return_value = Response()
+        req.return_value.status_code = 200
+        req.return_value.request = PreparedRequest()
+        req.return_value._content = appengine.ListAuthorizedDomainsResponse.to_json(
+            appengine.ListAuthorizedDomainsResponse()
+        )
+
+        request = appengine.ListAuthorizedDomainsRequest()
+        metadata = [
+            ("key", "val"),
+            ("cephalopod", "squid"),
+        ]
+        pre.return_value = request, metadata
+        post.return_value = appengine.ListAuthorizedDomainsResponse()
+
+        client.list_authorized_domains(
+            request,
+            metadata=[
+                ("key", "val"),
+                ("cephalopod", "squid"),
+            ],
+        )
+
+        pre.assert_called_once()
+        post.assert_called_once()
+
+
+def test_list_authorized_domains_rest_bad_request(
+    transport: str = "rest", request_type=appengine.ListAuthorizedDomainsRequest
+):
+    client = AuthorizedDomainsClient(
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport=transport,
+    )
+
+    # send a request that will satisfy transcoding
+    request_init = {"parent": "apps/sample1"}
+    request = request_type(**request_init)
+
+    # Mock the http request call within the method and fake a BadRequest error.
+    with mock.patch.object(Session, "request") as req, pytest.raises(
+        core_exceptions.BadRequest
+    ):
+        # Wrap the value into a proper Response obj
+        response_value = Response()
+        response_value.status_code = 400
+        response_value.request = Request()
+        req.return_value = response_value
+        client.list_authorized_domains(request)
+
+
+def test_list_authorized_domains_rest_pager(transport: str = "rest"):
+    client = AuthorizedDomainsClient(
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport=transport,
+    )
+
+    # Mock the http request call within the method and fake a response.
+    with mock.patch.object(Session, "request") as req:
+        # TODO(kbandes): remove this mock unless there's a good reason for it.
+        # with mock.patch.object(path_template, 'transcode') as transcode:
+        # Set the response as a series of pages
+        response = (
+            appengine.ListAuthorizedDomainsResponse(
+                domains=[
+                    domain.AuthorizedDomain(),
+                    domain.AuthorizedDomain(),
+                    domain.AuthorizedDomain(),
+                ],
+                next_page_token="abc",
+            ),
+            appengine.ListAuthorizedDomainsResponse(
+                domains=[],
+                next_page_token="def",
+            ),
+            appengine.ListAuthorizedDomainsResponse(
+                domains=[
+                    domain.AuthorizedDomain(),
+                ],
+                next_page_token="ghi",
+            ),
+            appengine.ListAuthorizedDomainsResponse(
+                domains=[
+                    domain.AuthorizedDomain(),
+                    domain.AuthorizedDomain(),
+                ],
+            ),
+        )
+        # Two responses for two calls
+        response = response + response
+
+        # Wrap the values into proper Response objs
+        response = tuple(
+            appengine.ListAuthorizedDomainsResponse.to_json(x) for x in response
+        )
+        return_values = tuple(Response() for i in response)
+        for return_val, response_val in zip(return_values, response):
+            return_val._content = response_val.encode("UTF-8")
+            return_val.status_code = 200
+        req.side_effect = return_values
+
+        sample_request = {"parent": "apps/sample1"}
+
+        pager = client.list_authorized_domains(request=sample_request)
+
+        results = list(pager)
+        assert len(results) == 6
+        assert all(isinstance(i, domain.AuthorizedDomain) for i in results)
+
+        pages = list(client.list_authorized_domains(request=sample_request).pages)
+        for page_, token in zip(pages, ["abc", "def", "ghi", ""]):
+            assert page_.raw_page.next_page_token == token
+
+
 def test_credentials_transport_error():
     # It is an error to provide credentials and a transport instance.
     transport = transports.AuthorizedDomainsGrpcTransport(
@@ -1136,6 +1356,7 @@ def test_transport_get_channel():
     [
         transports.AuthorizedDomainsGrpcTransport,
         transports.AuthorizedDomainsGrpcAsyncIOTransport,
+        transports.AuthorizedDomainsRestTransport,
     ],
 )
 def test_transport_adc(transport_class):
@@ -1150,6 +1371,7 @@ def test_transport_adc(transport_class):
     "transport_name",
     [
         "grpc",
+        "rest",
     ],
 )
 def test_transport_kind(transport_name):
@@ -1289,6 +1511,7 @@ def test_authorized_domains_transport_auth_adc(transport_class):
     [
         transports.AuthorizedDomainsGrpcTransport,
         transports.AuthorizedDomainsGrpcAsyncIOTransport,
+        transports.AuthorizedDomainsRestTransport,
     ],
 )
 def test_authorized_domains_transport_auth_gdch_credentials(transport_class):
@@ -1390,11 +1613,23 @@ def test_authorized_domains_grpc_transport_client_cert_source_for_mtls(transport
             )
 
 
+def test_authorized_domains_http_transport_client_cert_source_for_mtls():
+    cred = ga_credentials.AnonymousCredentials()
+    with mock.patch(
+        "google.auth.transport.requests.AuthorizedSession.configure_mtls_channel"
+    ) as mock_configure_mtls_channel:
+        transports.AuthorizedDomainsRestTransport(
+            credentials=cred, client_cert_source_for_mtls=client_cert_source_callback
+        )
+        mock_configure_mtls_channel.assert_called_once_with(client_cert_source_callback)
+
+
 @pytest.mark.parametrize(
     "transport_name",
     [
         "grpc",
         "grpc_asyncio",
+        "rest",
     ],
 )
 def test_authorized_domains_host_no_port(transport_name):
@@ -1405,7 +1640,11 @@ def test_authorized_domains_host_no_port(transport_name):
         ),
         transport=transport_name,
     )
-    assert client.transport._host == ("appengine.googleapis.com:443")
+    assert client.transport._host == (
+        "appengine.googleapis.com:443"
+        if transport_name in ["grpc", "grpc_asyncio"]
+        else "https://appengine.googleapis.com"
+    )
 
 
 @pytest.mark.parametrize(
@@ -1413,6 +1652,7 @@ def test_authorized_domains_host_no_port(transport_name):
     [
         "grpc",
         "grpc_asyncio",
+        "rest",
     ],
 )
 def test_authorized_domains_host_with_port(transport_name):
@@ -1423,7 +1663,33 @@ def test_authorized_domains_host_with_port(transport_name):
         ),
         transport=transport_name,
     )
-    assert client.transport._host == ("appengine.googleapis.com:8000")
+    assert client.transport._host == (
+        "appengine.googleapis.com:8000"
+        if transport_name in ["grpc", "grpc_asyncio"]
+        else "https://appengine.googleapis.com:8000"
+    )
+
+
+@pytest.mark.parametrize(
+    "transport_name",
+    [
+        "rest",
+    ],
+)
+def test_authorized_domains_client_transport_session_collision(transport_name):
+    creds1 = ga_credentials.AnonymousCredentials()
+    creds2 = ga_credentials.AnonymousCredentials()
+    client1 = AuthorizedDomainsClient(
+        credentials=creds1,
+        transport=transport_name,
+    )
+    client2 = AuthorizedDomainsClient(
+        credentials=creds2,
+        transport=transport_name,
+    )
+    session1 = client1.transport.list_authorized_domains._session
+    session2 = client2.transport.list_authorized_domains._session
+    assert session1 != session2
 
 
 def test_authorized_domains_grpc_transport_channel():
@@ -1694,6 +1960,7 @@ async def test_transport_close_async():
 
 def test_transport_close():
     transports = {
+        "rest": "_session",
         "grpc": "_grpc_channel",
     }
 
@@ -1711,6 +1978,7 @@ def test_transport_close():
 
 def test_client_ctx():
     transports = [
+        "rest",
         "grpc",
     ]
     for transport in transports:
